<?php

namespace Drupal\elasticsearch_helper_content;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Provides the Elasticsearch entity normalizer plugin manager.
 */
class ElasticsearchEntityNormalizerManager extends DefaultPluginManager implements ElasticsearchEntityNormalizerManagerInterface {

  /**
   * Constructs a new ElasticsearchEntityNormalizerManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/ElasticsearchNormalizer/Entity', $namespaces, $module_handler, 'Drupal\elasticsearch_helper_content\Plugin\ElasticsearchNormalizer\Entity\EntityNormalizerInterface', 'Drupal\elasticsearch_helper_content\Annotation\ElasticsearchEntityNormalizer');

    $this->alterInfo('elasticsearch_normalizer_entity_info');
    $this->setCacheBackend($cache_backend, 'elasticsearch_normalizer_entity_plugins');
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinitions() {
    $definitions = parent::getDefinitions();

    $callback = ['Drupal\Component\Utility\SortArray', 'sortByWeightElement'];
    uasort($definitions, $callback);

    return $definitions;
  }

}
